DynamicError

Enum DynamicError 

pub enum DynamicError<E = ()> {
    InvalidTransition {
        from: &'static str,
        event: &'static str,
    },
    GuardFailed {
        guard: &'static str,
        event: &'static str,
    },
    ActionFailed {
        action: &'static str,
        event: &'static str,
    },
    CallbackFailed {
        action: &'static str,
        event: &'static str,
        source: E,
    },
    WrongState {
        expected: &'static str,
        actual: &'static str,
        operation: &'static str,
    },
}
Error returned when dynamic dispatch fails.

This error type is used by the dynamic mode wrapper when runtime event dispatch encounters errors like invalid transitions or guard failures.

Variants



InvalidTransition

Attempted to trigger an event that’s not valid from the current state.

Fields

from: &'static str
event: &'static str


GuardFailed

A guard callback failed during the transition.

Fields

guard: &'static str
event: &'static str


ActionFailed

An action callback failed during the transition.

Fields

action: &'static str
event: &'static str


CallbackFailed

A before/after callback returned a user-defined error.

Fields

action: &'static str
event: &'static str
source: E


WrongState

Attempted to access or modify state data when in wrong state.

Fields

expected: &'static str
actual: &'static str
operation: &'static str

Implementations

Source

impl<E> DynamicError<E>

pub fn invalid_transition(from: &'static str, event: &'static str) -> Self

pub fn guard_failed(guard: &'static str, event: &'static str) -> Self

pub fn action_failed(action: &'static str, event: &'static str) -> Self

pub fn callback_failed( action: &'static str, event: &'static str, source: E, ) -> Self

pub fn wrong_state( expected: &'static str, actual: &'static str, operation: &'static str, ) -> Self

pub fn from_guard_error(err: GuardError) -> Self

Convert from GuardError to DynamicError.

pub fn from_event_error(err: EventError<E>) -> Self