pub enum DynamicError<E = ()> {
InvalidTransition {
from: &'static str,
event: &'static str,
},
GuardFailed {
guard: &'static str,
event: &'static str,
},
ActionFailed {
action: &'static str,
event: &'static str,
},
CallbackFailed {
action: &'static str,
event: &'static str,
source: E,
},
WrongState {
expected: &'static str,
actual: &'static str,
operation: &'static str,
},
}Expand description
Error returned when dynamic dispatch fails.
This error type is used by the dynamic mode wrapper when runtime event dispatch encounters errors like invalid transitions or guard failures.
Variants
InvalidTransition
Attempted to trigger an event that’s not valid from the current state.
GuardFailed
A guard callback failed during the transition.
ActionFailed
An action callback failed during the transition.
CallbackFailed
A before/after callback returned a user-defined error.
WrongState
Attempted to access or modify state data when in wrong state.
Implementations
Sourceimpl<E> DynamicError<E>
impl<E> DynamicError<E>
pub fn invalid_transition(from: &'static str, event: &'static str) -> Self
pub fn guard_failed(guard: &'static str, event: &'static str) -> Self
pub fn action_failed(action: &'static str, event: &'static str) -> Self
pub fn callback_failed( action: &'static str, event: &'static str, source: E, ) -> Self
pub fn wrong_state( expected: &'static str, actual: &'static str, operation: &'static str, ) -> Self
Sourcepub fn from_guard_error(err: GuardError) -> Self
pub fn from_guard_error(err: GuardError) -> Self
Convert from GuardError to DynamicError.
pub fn from_event_error(err: EventError<E>) -> Self